# robot_monitoring_tools/tools/schemas.py
from pydantic import BaseModel, Field
from typing import Optional, List
from datetime import datetime

class BatteryCheckRequest(BaseModel):
    battery: int = Field(..., description="Battery level to check")
    condition: str = Field(..., description="Search Battery Condition(lower,higher)")

class BatteryCheckResponse(BaseModel):
    robot_name: str = Field(..., description="Robot Name")
    serial_number: str = Field(..., description="Robot Serial Number")
    battery: int = Field(..., description="Robot Battery Level")

class LastTransferDateRequest(BaseModel):
    collect_date: datetime = Field(..., description="Base Data. If None, current date will be used")
    today_date : datetime = Field(datetime.now(), description="Today Date")
class LastTransferDateResponse(BaseModel):
    robot_name: str = Field(..., description="Robot Name")
    serial_number: str = Field(..., description="Robot Serial Number")
    collect_date: str = Field(..., description="Last Transfer Date")

class EventResponse(BaseModel):
    robot_name: str
    serial_number: str
    occurred_date: datetime
    event_code: str
    
    