import os
import sys
import sphinx_rtd_theme

sys.path.insert(0, os.path.abspath('../..'))

project = 'robot_monitoring_tools'
copyright = '2025, ljh'
author = 'ljh'

extensions = [
    'sphinx.ext.autodoc',
    'sphinx.ext.napoleon',
    'sphinx.ext.viewcode',
    'sphinx.ext.intersphinx',
    'sphinx_rtd_theme'
]

templates_path = ['_templates']
exclude_patterns = []

html_theme = 'sphinx_rtd_theme'
html_static_path = ['_static']

# Napoleon 설정
napoleon_google_docstring = True
napoleon_numpy_docstring = True
napoleon_include_init_with_doc = True

language = 'ko'